==> ralite_1.03.zip: ra_core/application/config/SettingConfig.php <==
<?php
/**
 * Research Artisan Lite: Website Access Analyzer
 * Copyright (C) 2009 Research Artisan Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * @copyright Copyright (C) 2009 Research Artisan Project
 * @license GNU General Public License (see license.txt)
 * @author ossi
 */
class SettingConfig {

  public static $okSeconds = array(
                    '10' => '10秒',
                    '20' => '20秒',
                    '30' => '30秒',
                    '60' => '1分',
                    '120' => '2分',
                    '300' => '5分',
                    '600' => '10分',
                    '900' => '15分',
                    '1800' => '30分',
                    '3600' => '1時間',
                    '7200' => '2時間'
  );

  public static $againSeconds = array(
                    '10' => '10秒',
                    '20' => '20秒',
                    '30' => '30秒',
                    '60' => '1分',
                    '120' => '2分',
                    '300' => '5分',
                    '600' => '10分',
                    '900' => '15分',
                    '1800' => '30分',
                    '3600' => '1時間',
                    '7200' => '2時間'
  );

  public static $dispViews = array(
                    '10' => '10件',
                    '20' => '20件',
                    '30' => '30件',
                    '40' => '40件',
                    '50' => '50件',
                    '60' => '60件',
                    '70' => '70件',
                    '80' => '80件',
                    '90' => '90件',
                    '100' => '100件'
  );

}
?>

==> ralite_1.17.zip: ra_core/application/config/SettingConfig.php <==
<?php
/**
 * Research Artisan Lite: Website Access Analyzer
 * Copyright (C) 2009 Research Artisan Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * @copyright Copyright (C) 2009 Research Artisan Project
 * @license GNU General Public License (see license.txt)
 * @author ossi
 */
class SettingConfig {

  public static $okSeconds = array(
                    '10' => '10秒',
                    '20' => '20秒',
                    '30' => '30秒',
                    '60' => '1分',
                    '120' => '2分',
                    '300' => '5分',
                    '600' => '10分',
                    '900' => '15分',
                    '1800' => '30分',
                    '3600' => '1時間',
                    '7200' => '2時間'
  );

  public static $againSeconds = array(
                    '10' => '10秒',
                    '20' => '20秒',
                    '30' => '30秒',
                    '60' => '1分',
                    '120' => '2分',
                    '300' => '5分',
                    '600' => '10分',
                    '900' => '15分',
                    '1800' => '30分',
                    '3600' => '1時間',
                    '7200' => '2時間'
  );

  public static $dispViews = array(
                    '10' => '10件',
                    '20' => '20件',
                    '30' => '30件',
                    '40' => '40件',
                    '50' => '50件',
                    '60' => '60件',
                    '70' => '70件',
                    '80' => '80件',
                    '90' => '90件',
                    '100' => '100件'
  );

  public static $mailViews = array(
                    '10' => '10件',
                    '20' => '20件',
                    '30' => '30件',
                    '40' => '40件',
                    '50' => '50件',
                    '60' => '60件',
                    '70' => '70件',
                    '80' => '80件',
                    '90' => '90件',
                    '100' => '100件'
  );

  public static $appLogLevels = array(
                    'NONE' => '出力しない',
                    'FATAL' => '致命的エラー',
                    'ERROR' => 'エラー',
                    'WARNING' => '警告',
                    'INFO' => 'インフォメーション',
                    'DEBUG' => 'デバッグ',
                    'ALL' => '全て'
  );

}
?>
